@@ -94,12 +94,12 @@ def init():
 
     # register all Actions available for all SOM classes
     class_names = [
-        'Asset', 'TimeLog', 'Department', 'Entity', 'FilenameTemplate',
-        'Group', 'ImageFormat', 'Link', 'Message', 'Note', 'Page',
-        'Permission', 'Project', 'Repository', 'Review', 'Scene', 'Sequence',
-        'Shot', 'SimpleEntity', 'Status', 'StatusList', 'Structure', 'Studio',
-        'Tag', 'Task', 'Ticket', 'TicketLog', 'Type', 'User', 'Vacation',
-        'Version']
+        'Asset', 'TimeLog', 'Client', 'Department', 'Entity',
+        'FilenameTemplate', 'Group', 'ImageFormat', 'Link', 'Message', 'Note',
+        'Page', 'Permission', 'Project', 'Repository', 'Review', 'Scene',
+        'Sequence', 'Shot', 'SimpleEntity', 'Status', 'StatusList',
+        'Structure', 'Studio', 'Tag', 'Task', 'Ticket', 'TicketLog', 'Type',
+        'User', 'Vacation', 'Version']
 
     for class_name in class_names:
         _temp = __import__(
@@ -107,7 +107,7 @@ def init():
             globals(),
             locals(),
             [class_name],
-            -1
+            0
         )
         class_ = eval("_temp." + class_name)
         register(class_)
@@ -134,9 +134,45 @@ def init():
                            status_names=defaults.review_status_names,
                            status_codes=defaults.review_status_codes)
 
+    # create alembic revision table
+    create_alembic_table()
+
     logger.debug('finished initializing the database')
 
 
+def create_alembic_table():
+    """creates the default alembic_version table and creates the data so that
+    any new database will be considered as the latest version
+    """
+    # Now, this is not the correct way of doing, there is a proper way of doing
+    # it and it is explained nicely in the Alembic library documentation.
+    #
+    # But it is simply not working when Stalker is installed as a package.
+    #
+    # So as a workaround here we are doing it manually
+    # don't forget to update the version_num (and the corresponding test
+    # whenever a new alembic revision is created)
+
+    version_num = '5999269aad30'
+
+    logger.debug('creating alembic_version table with version_num: %s' %
+                 version_num)
+
+    from sqlalchemy import Table, Column, Text
+    alembic_version_table = Table(
+        'alembic_version', Base.metadata,
+        Column('version_num', Text)
+    )
+
+    engine = DBSession.connection().engine
+    Base.metadata.create_all(engine)
+
+    ins = alembic_version_table.insert().values(version_num=version_num)
+    DBSession.connection().execute(ins)
+
+    logger.debug('alembic_version table is created and initialized')
+
+
 def __create_admin__():
     """creates the admin
     """
