@@ -18,7 +18,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 import os
-import pickle
+import json
 import re
 import base64
 import datetime
@@ -39,72 +39,6 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging_level)
 
 
-def group_finder(login, request):
-    """Returns the group of the given login. The login name will be in
-    'User:{login}' format.
-
-    :param login: The login of the user, both '{login}' and 'User:{login}'
-      format is accepted.
-
-    :param request: The Request object
-
-    :return: Will return the groups of the user in ['Group:{group_name}']
-      format.
-    """
-
-    if ':' in login:
-        login = login.split(':')[1]
-
-    # return the group of the given User object
-    user_obj = User.query.filter_by(login=login).first()
-
-    if user_obj:
-        # just return the groups names if there is any group
-        groups = user_obj.groups
-        if len(groups):
-            return map(lambda x: 'Group:' + x.name, groups)
-
-    return []
-
-
-class RootFactory(object):
-    """The main purpose of having a root factory is to generate the objects
-    used as the context by the request. But in our case it just used to
-    determine the default ACLs.
-    """
-
-    @property
-    def __acl__(self):
-        # create the default acl and give admins all the permissions
-        all_permissions = map(
-            lambda x: x.action + '_' + x.class_name,
-            Permission.query.all()
-        )
-
-        # start with default ACLs
-
-        ACLs = [
-            ('Allow', 'Group:' + defaults.admin_department_name,
-             all_permissions),
-            ('Allow', 'User:' + defaults.admin_name, all_permissions)
-        ]
-
-        # get all users and their ACLs
-        all_users = User.query.all()
-        for user in all_users:
-            ACLs.extend(user.__acl__)
-
-        # get all groups and their ACLs
-        all_groups = Group.query.all()
-        for group in all_groups:
-            ACLs.extend(group.__acl__)
-
-        return ACLs
-
-    def __init__(self, request):
-        pass
-
-
 class Permission(Base):
     """A class to hold permissions.
 
@@ -198,11 +132,12 @@ class Permission(Base):
     def _validate_access(self, access):
         """validates the given access value
         """
-        if not isinstance(access, (str, unicode)):
+        if not isinstance(access, str):
             raise TypeError(
-                '%s.access should be an instance of str or unicode '
-                'not %s' % (self.__class__.__name__,
-                            access.__class__.__name__)
+                '%s.access should be an instance of str not %s' % (
+                    self.__class__.__name__,
+                    access.__class__.__name__
+                )
             )
 
         if access not in ['Allow', 'Deny']:
@@ -223,10 +158,9 @@ class Permission(Base):
     def _validate_class_name(self, class_name):
         """validates the given class_name value
         """
-        if not isinstance(class_name, (str, unicode)):
+        if not isinstance(class_name, str):
             raise TypeError(
-                '%s.class_name should be an instance of str or '
-                'unicode not %s' %
+                '%s.class_name should be an instance of str not %s' %
                 (self.__class__.__name__, class_name.__class__.__name__)
             )
 
@@ -246,10 +180,9 @@ class Permission(Base):
         """validates the given action value
         """
 
-        if not isinstance(action, (str, unicode)):
+        if not isinstance(action, str):
             raise TypeError(
-                '%s.action should be an instance of str or unicode '
-                'not %s' %
+                '%s.action should be an instance of str not %s' %
                 (self.__class__.__name__, action.__class__.__name__)
             )
 
@@ -335,6 +268,11 @@ class Group(Entity, ACLMixin):
 
         return user
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
 
 class User(Entity, ACLMixin):
     """The user class is designed to hold data about a User in the system.
@@ -384,14 +322,19 @@ class User(Entity, ACLMixin):
     :param email: holds the e-mail of the user, should be in [part1]@[part2]
       format
 
-    :type email: str, unicode
+    :type email: str
 
     :param login: This is the login name of the user, it should be all lower
-      case. Giving a string or unicode that has uppercase letters, it will be
-      converted to lower case. It can not be an empty string or None and it can
-      not contain any white space inside.
+      case. Giving a string that has uppercase letters, it will be converted to
+      lower case. It can not be an empty string or None and it can not contain
+      any white space inside.
 
-    :type login: str, unicode
+    :type login: str
+
+    :param company: The client which the user is affiliated with. A user can be
+    affiliated with one company only. Default value is None.
+
+    :type company: :class:`.Client`
 
     :param departments: It is the departments that the user is a part of. It
       should be a list of Department objects. One user can be listed in
@@ -404,7 +347,7 @@ class User(Entity, ACLMixin):
       password with a raw password use :meth:`.check_password` and to set the
       password you can use the :attr:`.password` property directly.
 
-    :type password: str, unicode
+    :type password: str
 
     :param groups: It is a list of :class:`.Group` instances that this user
       belongs to.
@@ -441,11 +384,23 @@ class User(Entity, ACLMixin):
         this user is a part of""",
     )
 
+    company_id = Column(Integer, ForeignKey("Clients.id"))
+    company = relationship(
+        "Client",
+        primaryjoin="Users.c.company_id==Clients.c.id",
+        back_populates="users",
+        uselist=False,
+        doc="""The client company which the user is affiliated with.
+
+        Should be an instance of :class:`.Client`, can also be set to None.
+        """
+    )
+
     email = Column(
         String(256),
         unique=True,
         nullable=False,
-        doc="""email of the user, accepts strings or unicode"""
+        doc="email of the user, accepts string"
     )
 
     password = Column(
@@ -562,6 +517,7 @@ class User(Entity, ACLMixin):
             email=None,
             password=None,
             departments=None,
+            company=None,
             groups=None,
             efficiency=1.0,
             **kwargs):
@@ -575,6 +531,8 @@ class User(Entity, ACLMixin):
             departments = []
         self.departments = departments
 
+        self.company = company
+
         self.email = email
 
         # to be able to mangle the password do it like this
@@ -605,10 +563,10 @@ class User(Entity, ACLMixin):
             self.login == other.login and \
             self.name == other.name
 
-    def __ne__(self, other):
-        """the inequality operator
+    def __hash__(self):
+        """the overridden __hash__ method
         """
-        return not self.__eq__(other)
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
 
     @validates("login")
     def _validate_login(self, key, login):
@@ -647,15 +605,29 @@ class User(Entity, ACLMixin):
             )
         return department
 
+    @validates("company")
+    def _validate_company(self, key, client):
+        """validates the given company value
+        """
+        from stalker.models.client import Client
+
+        if client is not None:
+            if not isinstance(client, Client):
+                raise TypeError(
+                    "%s.client should be instance of "
+                    "stalker.models.client.Client not %s" %
+                    (self.__class__.__name__, client.__class__.__name__)
+                )
+        return client
+
     @validates("email")
     def _validate_email(self, key, email_in):
         """validates the given email value
         """
-        # check if email_in is an instance of string or unicode
-        if not isinstance(email_in, (str, unicode)):
+        # check if email_in is an instance of string
+        if not isinstance(email_in, str):
             raise TypeError(
-                "%s.email should be an instance of string or "
-                "unicode not %s" %
+                "%s.email should be an instance of str not %s" %
                 (self.__class__.__name__, email_in.__class__.__name__)
             )
         return self._validate_email_format(email_in)
@@ -745,7 +717,7 @@ class User(Entity, ACLMixin):
             raise ValueError("raw_password can not be empty string")
 
         # mangle the password
-        return base64.encodestring(password_in)
+        return base64.b64encode(password_in.encode('utf-8'))
 
     def check_password(self, raw_password):
         """Checks the given raw_password.
@@ -756,7 +728,8 @@ class User(Entity, ACLMixin):
         Checks the given raw password with the given encrypted password.
         Handles the encryption process behind the scene.
         """
-        return self.password == base64.encodestring(str(raw_password))
+        return self.password == \
+            base64.b64encode(bytes(raw_password.encode('utf-8')))
 
     @validates("groups")
     def _validate_groups(self, key, group):
@@ -921,16 +894,59 @@ class LocalSession(object):
         self.session_data = None
         self.load()
 
+    @classmethod
+    def default_json_serializer(cls, obj):
+        """default serializer for json data
+        """
+        if isinstance(obj, datetime.datetime):
+            return cls.datetime_to_millis(obj)
+        elif isinstance(obj, User):
+            return User.id
+        elif isinstance(obj, int):
+            return obj
+
+    @classmethod
+    def datetime_to_millis(cls, dt):
+        """Default JSON serializer for datetime objects.
+
+        code is based on the answer of Jay Taylor in
+        http://stackoverflow.com/questions/11875770/how-to-overcome-datetime-datetime-not-json-serializable-in-python
+
+        :param dt: datetime.datetime instance
+        """
+        import calendar
+
+        if isinstance(dt, datetime.datetime):
+            if dt.utcoffset() is not None:
+                obj = dt - dt.utcoffset()
+        millis = int(
+            calendar.timegm(dt.timetuple()) * 1000 +
+            dt.microsecond / 1000
+        )
+        return millis
+
+    @classmethod
+    def millis_to_datetime(cls, millis):
+        """
+        :param int millis: an int value showing the millis from unix EPOCH
+        :return:
+        """
+        epoch = datetime.datetime(1970, 1, 1)
+        return epoch + datetime.timedelta(milliseconds=millis)
+
     def load(self):
         """loads the data from the saved local session
         """
         try:
-            with open(LocalSession.session_file_full_path(), 'rb') as s:
+            with open(LocalSession.session_file_full_path(), 'r') as s:
                 # try:
-                unpickled_object = pickle.load(s)
-                if unpickled_object.valid_to > datetime.datetime.now():
+                json_object = json.load(s)
+                valid_to = self.millis_to_datetime(json_object.get('valid_to'))
+                if valid_to > datetime.datetime.now():
                     # fill __dict__ with the loaded one
-                    self.__dict__ = unpickled_object.__dict__
+                    self.valid_to = valid_to
+                    self.logged_in_user_id = \
+                        json_object.get('logged_in_user_id')
         except IOError:
             pass
 
@@ -951,9 +967,12 @@ class LocalSession(object):
     def save(self):
         """remembers the data in user local file system
         """
-        self.valid_to = datetime.datetime.now() + datetime.timedelta(10)
+        self.valid_to = datetime.datetime.now() + datetime.timedelta(days=10)
         # serialize self
-        dumped_data = pickle.dumps(self)
+        dumped_data = json.dumps({
+            'valid_to': self.valid_to,
+            'logged_in_user_id': self.logged_in_user_id
+        }, default=self.default_json_serializer)
         logger.debug('dumped session data : %s' % dumped_data)
         self._write_data(dumped_data)
 
@@ -991,8 +1010,8 @@ class LocalSession(object):
             # dir exists
             pass
         finally:
-            with open(file_full_path, 'wb') as data_file:
-                data_file.writelines(data)
+            with open(file_full_path, 'w') as data_file:
+                data_file.write(data)
 
 
 # USER_PERMISSIONGROUPS
