@@ -104,6 +104,11 @@ class Department(Entity):
         return super(Department, self).__eq__(other) and \
             isinstance(other, Department)
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
     @validates("members")
     def _validate_members(self, key, member):
         """validates the given member attribute
