@@ -90,3 +90,8 @@ class Scene(Entity, ProjectMixin, CodeMixin):
         """the equality operator
         """
         return isinstance(other, Scene) and super(Scene, self).__eq__(other)
+
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
