@@ -17,8 +17,9 @@
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-from sqlalchemy import Column, Integer, ForeignKey, String, Text
-from sqlalchemy.orm import validates, synonym
+
+from sqlalchemy import Column, Integer, ForeignKey, Text
+from sqlalchemy.orm import validates
 from stalker import ProjectMixin, Entity
 
 
