@@ -18,8 +18,9 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import unittest2
+import unittest
 import datetime
+import json
 
 import stalker
 from stalker.db import DBSession
@@ -33,7 +34,7 @@ class NewClass(SimpleEntity):
     __strictly_typed__ = True
 
 
-class SimpleEntityTester(unittest2.TestCase):
+class SimpleEntityTester(unittest.TestCase):
     """testing the SimpleEntity class
     """
 
@@ -45,7 +46,13 @@ class SimpleEntityTester(unittest2.TestCase):
             name="Test User",
             login="testuser",
             email="test@user.com",
-            password="test"
+            password="test",
+            generic_text=json.dumps(
+                {
+                    'Phone number': '123'
+                },
+                sort_keys=True
+            ),
         )
 
         self.date_created = datetime.datetime(2010, 10, 21, 3, 8, 0)
@@ -60,6 +67,12 @@ class SimpleEntityTester(unittest2.TestCase):
             "updated_by": self.test_user,
             "date_created": self.date_created,
             "date_updated": self.date_updated,
+            'generic_text': json.dumps(
+                {
+                    'Phone number': '123'
+                },
+                sort_keys=True
+            ),
         }
 
         # create a proper SimpleEntity to use it later in the tests
@@ -138,9 +151,9 @@ class SimpleEntityTester(unittest2.TestCase):
         self.test_simple_entity.name = ''
         self.assertTrue(self.test_simple_entity)
 
-    def test_name_argument_is_not_a_string_or_unicode_instance_or_None(self):
+    def test_name_argument_is_not_a_string_instance_or_None(self):
         """testing if a TypeError will be raised when the name argument is not
-        a string or unicode or None
+        a string or None
         """
         test_values = [
             12132,
@@ -152,9 +165,9 @@ class SimpleEntityTester(unittest2.TestCase):
             self.kwargs["name"] = test_value
             self.assertRaises(TypeError, SimpleEntity, **self.kwargs)
 
-    def test_name_attribute_is_not_string_or_unicode_or_None(self):
-        """testing if a TypeError will be raised when the name attribute is
-        not a string or unicode or None
+    def test_name_attribute_is_not_string_or_None(self):
+        """testing if a TypeError will be raised when the name attribute is not
+        a string or None
         """
         test_values = [
             12132, [1, "name"], {"a": "name"}
@@ -220,20 +233,51 @@ class SimpleEntityTester(unittest2.TestCase):
         self.test_simple_entity.description = None
         self.assertEqual(self.test_simple_entity.description, "")
 
-    def test_description_argument_is_not_a_string_or_unicode(self):
+    def test_description_argument_is_not_a_string(self):
         """testing if a TypeError will be raised when the description argument
-        value is not a string or unicode
+        value is not a string
         """
         self.kwargs['description'] = {'a': 'description'}
         self.assertRaises(TypeError, SimpleEntity, **self.kwargs)
 
-    def test_description_attribute_is_not_a_string_or_unicode(self):
+    def test_description_attribute_is_not_a_string(self):
         """testing if a TypeError will be raised when the description attribute
-        value is set to a value other than a string or unicide
+        value is set to a value other than a string
         """
         self.assertRaises(TypeError, setattr, self.test_simple_entity,
                           'description', ["a description"])
 
+    def test_generic_text_argument_None(self):
+        """testing if generic_text property will be converted to an empty
+        string if None is given as the generic_text argument
+        """
+        self.kwargs["generic_text"] = None
+        new_simple_entity = SimpleEntity(**self.kwargs)
+
+        self.assertEqual(new_simple_entity.generic_text, "")
+
+    def test_generic_text_attribute_None(self):
+        """testing if generic_text attribute will be converted to an empty
+        string if None is given as the generic_text attribute
+        """
+
+        self.test_simple_entity.generic_text = None
+        self.assertEqual(self.test_simple_entity.generic_text, "")
+
+    def test_generic_text_argument_is_not_a_string(self):
+        """testing if a TypeError will be raised when the generic_text argument
+        value is not a string
+        """
+        self.kwargs['generic_text'] = {'a': 'generic_text'}
+        self.assertRaises(TypeError, SimpleEntity, **self.kwargs)
+
+    def test_generic_text_attribute_is_not_a_string(self):
+        """testing if a TypeError will be raised when the generic_text
+        attribute value is set to a value other than a string
+        """
+        self.assertRaises(TypeError, setattr, self.test_simple_entity,
+                          'generic_text', ["a generic_text"])
+
     def test_equality(self):
         """testing the equality of two simple entities
         """
@@ -485,7 +529,7 @@ class SimpleEntityTester(unittest2.TestCase):
         """
         self.kwargs["type"] = None
         new_simple_entity = SimpleEntity(**self.kwargs)
-        self.assertIsInstance(new_simple_entity, SimpleEntity)
+        self.assertTrue(isinstance(new_simple_entity, SimpleEntity))
 
     def test_type_attribute_is_set_to_None(self):
         """testing if nothing will be happened when the type attribute is set
@@ -510,7 +554,7 @@ class SimpleEntityTester(unittest2.TestCase):
         self.kwargs["type"] = self.test_type
         # no error is expected
         new_simple_entity = SimpleEntity(**self.kwargs)
-        self.assertIsInstance(new_simple_entity, SimpleEntity)
+        self.assertTrue(isinstance(new_simple_entity, SimpleEntity))
 
     def test_type_attribute_accepts_only_Type_instances(self):
         """testing if a TypeError will be raised when the given type attribute
@@ -546,7 +590,7 @@ class SimpleEntityTester(unittest2.TestCase):
 
         # create a new instance and skip the Type attribute and expect a
         # TypeError
-        if self.kwargs.has_key("type"):
+        if "type" in self.kwargs:
             self.kwargs.pop("type")
 
         self.assertRaises(TypeError, NewClass, **self.kwargs)
@@ -580,7 +624,7 @@ class SimpleEntityTester(unittest2.TestCase):
             self.kwargs["type"] = test_value
             self.assertRaises(TypeError, NewClass, **self.kwargs)
 
-    def test___stalker_version__attribute_is_automatically_set_to_the_current_task_Stalker(self):
+    def test___stalker_version__attribute_is_automatically_set_to_the_current_Stalker_version(self):
         """testing if the __stalker_version__ is automatically set to the
         current version for the newly created SimpleEntities
         """
