@@ -18,7 +18,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import unittest2
+import unittest
 from stalker import Structure, FilenameTemplate, Type
 
 
@@ -35,7 +35,7 @@ class Link(object):
     pass
 
 
-class StructureTester(unittest2.TestCase):
+class StructureTester(unittest.TestCase):
     """tests the stalker.models.structure.Structure class
     """
 
@@ -147,7 +147,7 @@ class StructureTester(unittest2.TestCase):
         """
         self.kwargs.pop("templates")
         new_structure = Structure(**self.kwargs)
-        self.assertIsInstance(new_structure, Structure)
+        self.assertTrue(isinstance(new_structure, Structure))
 
     def test_templates_argument_can_be_None(self):
         """testing if no error will be raised when the templates argument is
@@ -155,7 +155,7 @@ class StructureTester(unittest2.TestCase):
         """
         self.kwargs["templates"] = None
         new_structure = Structure(**self.kwargs)
-        self.assertIsInstance(new_structure, Structure)
+        self.assertTrue(isinstance(new_structure, Structure))
 
     def test_templates_attribute_cannot_be_set_to_None(self):
         """testing if a TypeError will be raised when the templates attribute
@@ -192,7 +192,7 @@ class StructureTester(unittest2.TestCase):
         # test the correct value
         self.kwargs["templates"] = self.test_templates
         new_structure = Structure(**self.kwargs)
-        self.assertIsInstance(new_structure, Structure)
+        self.assertTrue(isinstance(new_structure, Structure))
 
     def test_templates_attribute_accpets_only_list_of_FilenameTemplate_instances(self):
         """testing if a TypeError will be raised when the templates attribute
