@@ -18,7 +18,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import unittest2
+import unittest
 
 from stalker.db.session import DBSession
 from stalker import (db, TicketLog, Asset, User, Note, Project, Repository,
@@ -31,7 +31,7 @@ logger = logging.getLogger("stalker.models.ticket")
 logger.setLevel(log.logging_level)
 
 
-class TicketTester(unittest2.TestCase):
+class TicketTester(unittest.TestCase):
     """Tests the :class:`~stalker.models.ticket.Ticket` class
     """
 
@@ -309,9 +309,9 @@ class TicketTester(unittest2.TestCase):
         ]
 
         new_ticket = Ticket(**self.kwargs)
-        self.assertItemsEqual(
-            self.kwargs['links'],
-            new_ticket.links
+        self.assertEqual(
+            sorted(self.kwargs['links'], key=lambda x: x.name),
+            sorted(new_ticket.links, key=lambda x: x.name)
         )
 
     def test_links_attribute_accepts_anything_derived_from_SimpleEntity(self):
@@ -326,7 +326,10 @@ class TicketTester(unittest2.TestCase):
             self.test_version
         ]
         self.test_ticket.links = links
-        self.assertItemsEqual(links, self.test_ticket.links)
+        self.assertEqual(
+            sorted(links, key=lambda x: x.name),
+            sorted(self.test_ticket.links, key=lambda x: x.name)
+        )
 
     def test_related_tickets_attribute_is_an_empty_list_on_init(self):
         """testing if the related_tickets attribute is an empty list on init
@@ -690,7 +693,7 @@ class TicketTester(unittest2.TestCase):
         self.test_ticket.resolve(resolution='fixed')
         self.assertEqual(self.test_ticket.resolution, 'fixed')
         ticket_log = self.test_ticket.reopen()
-        self.assertIsInstance(ticket_log, TicketLog)
+        self.assertTrue(isinstance(ticket_log, TicketLog))
         self.assertEqual(self.test_ticket.resolution, '')
 
     def test_reassign_will_set_the_owner(self):
@@ -699,7 +702,7 @@ class TicketTester(unittest2.TestCase):
         self.assertEqual(self.test_ticket.status, self.status_new)
         self.assertNotEqual(self.test_ticket.owner, self.test_user)
         ticket_log = self.test_ticket.reassign(assign_to=self.test_user)
-        self.assertIsInstance(ticket_log, TicketLog)
+        self.assertTrue(isinstance(ticket_log, TicketLog))
         self.assertEqual(self.test_ticket.owner, self.test_user)
 
     def test_accept_will_set_the_owner(self):
@@ -708,7 +711,7 @@ class TicketTester(unittest2.TestCase):
         self.assertEqual(self.test_ticket.status, self.status_new)
         self.assertNotEqual(self.test_ticket.owner, self.test_user)
         ticket_log = self.test_ticket.accept(created_by=self.test_user)
-        self.assertIsInstance(ticket_log, TicketLog)
+        self.assertTrue(isinstance(ticket_log, TicketLog))
         self.assertEqual(self.test_ticket.owner, self.test_user)
 
     def test_summary_argument_skipped(self):
@@ -734,19 +737,19 @@ class TicketTester(unittest2.TestCase):
         self.test_ticket.summary = None
         self.assertEqual(self.test_ticket.summary, '')
 
-    def test_summary_argument_is_not_a_string_or_unicode_instance(self):
+    def test_summary_argument_is_not_a_string(self):
         """testing if a TypeError will be raised when the summary argument
-        value is not a string or unicode
+        value is not a string
         """
         self.kwargs['summary'] = ['not a string instance']
         self.assertRaises(TypeError, Ticket, self.kwargs)
 
-    def test_summary_attribute_is_set_to_a_value_other_than_a_string_or_unicode(self):
+    def test_summary_attribute_is_set_to_a_value_other_than_a_string(self):
         """testing if the summary attribute is set to a value other than a
-        string or unicode
+        string
         """
         self.assertRaises(TypeError, setattr, self.test_ticket, 'summary',
-                          ['not a string or unicode'])
+                          ['not a string'])
 
     def test_summary_argument_is_working_properly(self):
         """testing if the summary argument value is passed to summary attribute
